==> pitivi_0.93.orig.tar.xz: pitivi-0.93/tests/test_mainwindow.py <==
# -*- coding: utf-8 -*-
#
# Copyright (c) 2013, Alex Băluț <alexandru.balut@gmail.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this program; if not, write to the
# Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
# Boston, MA 02110-1301, USA.

import mock
from unittest import TestCase

from gi.repository import GES

from pitivi.mainwindow import PitiviMainWindow


class TestMainWindow(TestCase):

    def setUp(self):
        app = mock.MagicMock()
        self.mainwindow = PitiviMainWindow(app)

    def testSwitchContextTab(self):
        for expected_tab, bElement in [
                (2, GES.TitleSource()),
                (1, GES.VideoTransition()),
                (0, GES.VideoUriSource()),
                (1, GES.VideoTransition()),
                (0, GES.ImageSource()),
                (1, GES.AudioTransition()),
                (0, GES.AudioUriSource()),
                (1, GES.AudioTransition())]:
            self.mainwindow.switchContextTab(bElement)
            self.assertEqual(expected_tab, self.mainwindow.context_tabs.get_current_page())
            # Make sure the tab does not change when using an invalid argument.
            self.mainwindow.switchContextTab("invalid")
            self.assertEqual(expected_tab, self.mainwindow.context_tabs.get_current_page())

==> pitivi_0.95.orig.tar.xz: pitivi-0.95/tests/test_mainwindow.py <==
# -*- coding: utf-8 -*-
#
# Copyright (c) 2013, Alex Băluț <alexandru.balut@gmail.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this program; if not, write to the
# Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
# Boston, MA 02110-1301, USA.

from unittest import TestCase, mock

from gi.repository import GES

from pitivi.mainwindow import PitiviMainWindow


class TestMainWindow(TestCase):

    def setUp(self):
        app = mock.MagicMock()
        self.mainwindow = PitiviMainWindow(app)

    def testSwitchContextTab(self):
        for expected_tab, bElement in [
                (2, GES.TitleClip()),
                (0, GES.SourceClip()),
                (1, GES.TransitionClip())]:
            self.mainwindow.switchContextTab(bElement)
            self.assertEqual(
                expected_tab, self.mainwindow.context_tabs.get_current_page(), bElement)
            # Make sure the tab does not change when using an invalid argument.
            self.mainwindow.switchContextTab("invalid")
            self.assertEqual(
                expected_tab, self.mainwindow.context_tabs.get_current_page())
